Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenlib/BLI_listbase_wrapper.hh')
-rw-r--r--source/blender/blenlib/BLI_listbase_wrapper.hh10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/blender/blenlib/BLI_listbase_wrapper.hh b/source/blender/blenlib/BLI_listbase_wrapper.hh
index 70f3135d9e3..a77e2d66458 100644
--- a/source/blender/blenlib/BLI_listbase_wrapper.hh
+++ b/source/blender/blenlib/BLI_listbase_wrapper.hh
@@ -20,16 +20,16 @@
/** \file
* \ingroup bli
*
* `BLI::ListBaseWrapper` is a typed wrapper for the ListBase struct. That makes it safer and more
* convenient to use in C++ in some cases. However, if you find yourself iterating over a linked
* list a lot, consider to convert it into a vector for further processing. This improves
* performance and debugability.
*/
#include "BLI_listbase.h"
#include "DNA_listBase.h"
-namespace BLI {
+namespace blender {
template<typename T> class ListBaseWrapper {
private:
@@ -110,6 +110,6 @@ template<typename T> class ListBaseWrapper {
}
};
-} /* namespace BLI */
+} /* namespace blender */
#endif /* __BLI_LISTBASE_WRAPPER_HH__ */
@@ -20,16 +20,16 @@
* \ingroup bli
*
- * `BLI::ListBaseWrapper` is a typed wrapper for the ListBase struct. That makes it safer and more
- * convenient to use in C++ in some cases. However, if you find yourself iterating over a linked
- * list a lot, consider to convert it into a vector for further processing. This improves
+ * `blender::ListBaseWrapper` is a typed wrapper for the ListBase struct. That makes it safer and
+ * more convenient to use in C++ in some cases. However, if you find yourself iterating over a
+ * linked list a lot, consider to convert it into a vector for further processing. This improves
* performance and debugability.
*/